BOOST_PP_TUPLE_ENUM

The BOOST_PP_TUPLE_ENUM macro converts a tuple to its comma-separated elements. The comma-separated elements are in the form of variadic data.

#### Usage

BOOST_PP_TUPLE_ENUM(size,tuple)
or
BOOST_PP_TUPLE_ENUM(...) (v)

#### Arguments

size
  The size of the tuple. Valid tuple sizes range from 1 to BOOST_PP_LIMIT_TUPLE.
tuple
  The tuple whose elements are to be converted.

#### Remarks

You can invoke the variadic version (v) as BOOST_PP_TUPLE_ENUM(tuple) or BOOST_PP_TUPLE_ENUM(size,tuple).

#### See Also

- BOOST_PP_LIMIT_TUPLE

#### Requirements

Header: <boost/preprocessor/tuple/enum.hpp>

#### Sample Code

    #include <boost/preprocessor/tuple/enum.hpp>

    #define TUPLE (B,O,O,S,T)

    BOOST_PP_TUPLE_ENUM(5,TUPLE) // expands to B, O, O, S, T

    // or for the variadic version (v)

    BOOST_PP_TUPLE_ENUM(TUPLE) // expands to B, O, O, S, T

© Copyright Housemarque Oy 2002
© Copyright Paul Mensonides 2002
© Copyright Edward Diener 2011,2013

Distributed under the Boost Software License, Version 1.0. (See accompanying file LICENSE_1_0.txt or copy at www.boost.org/LICENSE_1_0.txt)